"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DescriptionListTerm = void 0;
const tslib_1 = require("tslib");
const jsx_runtime_1 = require("react/jsx-runtime");
const description_list_1 = tslib_1.__importDefault(require("@patternfly/react-styles/css/components/DescriptionList/description-list"));
const react_styles_1 = require("@patternfly/react-styles");
const DescriptionListTerm = (_a) => {
    var { children, className, icon } = _a, props = tslib_1.__rest(_a, ["children", "className", "icon"]);
    return ((0, jsx_runtime_1.jsxs)("dt", Object.assign({ className: (0, react_styles_1.css)(description_list_1.default.descriptionListTerm, className) }, props, { children: [icon ? (0, jsx_runtime_1.jsx)("span", { className: (0, react_styles_1.css)(description_list_1.default.descriptionListTermIcon), children: icon }) : null, (0, jsx_runtime_1.jsx)("span", { className: (0, react_styles_1.css)(description_list_1.default.descriptionListText), children: children })] })));
};
exports.DescriptionListTerm = DescriptionListTerm;
exports.DescriptionListTerm.displayName = 'DescriptionListTerm';
//# sourceMappingURL=DescriptionListTerm.js.map